@@ -6,16 +6,15 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "fht.h"
 
 #include <math.h>
 #include <string.h>
 
-FHT::FHT(int n) :
-    m_buf(nullptr),
-    m_tab(nullptr),
-    m_log(nullptr)
+FHT::FHT(int n)
+    : m_buf(nullptr)
+    , m_tab(nullptr)
+    , m_log(nullptr)
 {
     if (n < 3) {
         m_num = 0;
@@ -31,7 +30,6 @@ FHT::FHT(int n) :
     }
 }
 
-
 FHT::~FHT()
 {
     delete[] m_buf;
@@ -39,7 +37,6 @@ FHT::~FHT()
     delete[] m_log;
 }
 
-
 void FHT::makeCasTable(void)
 {
     float d, *costab, *sintab;
@@ -55,33 +52,28 @@ void FHT::makeCasTable(void)
     }
 }
 
-
-float* FHT::copy(float *d, float *s)
+float *FHT::copy(float *d, float *s)
 {
     return (float *)memcpy(d, s, m_num * sizeof(float));
 }
 
-
-float* FHT::clear(float *d)
+float *FHT::clear(float *d)
 {
     return (float *)memset(d, 0, m_num * sizeof(float));
 }
 
-
 void FHT::scale(float *p, float d)
 {
     for (int i = 0; i < (m_num / 2); i++)
         *p++ *= d;
 }
 
-
 void FHT::ewma(float *d, float *s, float w)
 {
     for (int i = 0; i < (m_num / 2); i++, d++, s++)
         *d = *d * w + *s * (1 - w);
 }
 
-
 void FHT::logSpectrum(float *out, float *p)
 {
     int n = m_num / 2, i, j, k, *r;
@@ -108,7 +100,6 @@ void FHT::logSpectrum(float *out, float *p)
     }
 }
 
-
 void FHT::semiLogSpectrum(float *p)
 {
     float e;
@@ -119,7 +110,6 @@ void FHT::semiLogSpectrum(float *p)
     }
 }
 
-
 void FHT::spectrum(float *p)
 {
     power2(p);
@@ -127,7 +117,6 @@ void FHT::spectrum(float *p)
         *p = (float)sqrt(*p * .5);
 }
 
-
 void FHT::power(float *p)
 {
     power2(p);
@@ -135,7 +124,6 @@ void FHT::power(float *p)
         *p++ *= .5;
 }
 
-
 void FHT::power2(float *p)
 {
     int i;
@@ -148,7 +136,6 @@ void FHT::power2(float *p)
         *p = (*p * *p) + (*q * *q), p++;
 }
 
-
 void FHT::transform(float *p)
 {
     if (m_num == 8)
@@ -157,7 +144,6 @@ void FHT::transform(float *p)
         _transform(p, m_num, 0);
 }
 
-
 void FHT::transform8(float *p)
 {
     float a, b, c, d, e, f, g, h, b_f2, d_h2;
@@ -186,7 +172,6 @@ void FHT::transform8(float *p)
     *--p = aceg + bdfh;
 }
 
-
 void FHT::_transform(float *p, int n, int k)
 {
     if (n == 8) {
